roman_numerals: Manipulate well-formed Roman numerals
=====================================================

Description
-----------

A library for manipulating well-formed Roman numerals.

Integers between 1 and 3,999 (inclusive) are supported. Numbers beyond
this range will return an OutOfRangeError.

The classical system of roman numerals requires that the same character
may not appear more than thrice consecutively, meaning that ‘MMMCMXCIX’
(3,999) is the largest well-formed Roman numeral. The smallest is ‘I’ (1),
as there is no symbol for zero in Roman numerals.

License
-------

This project is licenced under the terms of either the Zero-Clause 
BSD licence or the CC0 1.0 Universal licence

Upstream Contact
----------------

https://pypi.org/project/roman-numerals-py/
